@@ -46,9 +46,11 @@ class KCList(KCObject):
 
     def _check_accessor(self, accessor):
         if not isinstance(accessor, int):
-            raise ValueError(f"expected int argument but got '{accessor}'")
+            from ..errors import unexpected_type_error
+            raise unexpected_type_error(int, accessor)
         if not 0 <= accessor < len(self.list):
-            raise IndexError(f"index {accessor} is out of range (0<={accessor}<{len(self.list)} evaluates to false)")
+            from ..errors import index_out_of_range_error
+            raise index_out_of_range_error(accessor, len(self.list))
 
     def __setitem__(self, key, value):
         self._check_accessor(key)
@@ -56,3 +58,10 @@ class KCList(KCObject):
 
     def __getitem__(self, item):
         return self.list[item]
+
+    def __iadd__(self, other):
+        if not isinstance(other, KCList):
+            from ..errors import unexpected_type_error
+            raise unexpected_type_error(KCList, other)
+        self.list += other.list
+        return self.list
